@@ -180,7 +180,7 @@ makeDocTypeHtml lines' = unlines
     , "--"
     , "-- Example:"
     , "--"
-    , "-- > docTypeHtml $ span $ text \"foo\""
+    , "-- > docTypeHtml $ span $ toHtml \"foo\""
     , "--"
     , "-- Result:"
     , "--"
@@ -201,7 +201,7 @@ makeParent tag = unlines
     , "--"
     , "-- Example:"
     , "--"
-    , "-- > " ++ function ++ " $ span $ text \"foo\""
+    , "-- > " ++ function ++ " $ span $ toHtml \"foo\""
     , "--"
     , "-- Result:"
     , "--"
@@ -401,22 +401,23 @@ html5 = HtmlVariant
     { version = ["Html5"]
     , docType = ["<!DOCTYPE HTML>"]
     , parents =
-        [ "a", "abbr", "address", "article", "aside", "audio", "b", "base"
+        [ "a", "abbr", "address", "article", "aside", "audio", "b"
         , "bdo", "blockquote", "body", "button", "canvas", "caption", "cite"
         , "code", "colgroup", "command", "datalist", "dd", "del", "details"
         , "dfn", "div", "dl", "dt", "em", "fieldset", "figcaption", "figure"
         , "footer", "form", "h1", "h2", "h3", "h4", "h5", "h6", "head", "header"
-        , "hgroup", "html", "i", "iframe", "ins", "keygen", "kbd", "label"
+        , "hgroup", "html", "i", "iframe", "ins", "kbd", "label"
         , "legend", "li", "map", "mark", "menu", "meter", "nav", "noscript"
         , "object", "ol", "optgroup", "option", "output", "p", "pre", "progress"
         , "q", "rp", "rt", "ruby", "samp", "script", "section", "select"
-        , "small", "source", "span", "strong", "style", "sub", "summary", "sup"
+        , "small", "span", "strong", "style", "sub", "summary", "sup"
         , "table", "tbody", "td", "textarea", "tfoot", "th", "thead", "time"
         , "title", "tr", "ul", "var", "video"
         ]
     , leafs =
-        [ "area", "br", "col", "embed", "hr", "img", "input", "meta", "link"
-        , "param"
+        -- http://www.whatwg.org/specs/web-apps/current-work/multipage/syntax.html#void-elements
+        [ "area", "base", "br", "col", "embed", "hr", "img", "input", "keygen"
+        , "link", "menuitem", "meta", "param", "source", "track", "wbr"
         ]
     , attributes =
         [ "accept", "accept-charset", "accesskey", "action", "alt", "async"
